<div class="row">

  <div class="col-md-6">

    <h3>Packages</h3>
    <ul class="list-inline">
      <% @package_prefixes.each do |prefix| %>
        <li><h5><a href="/packages/<%= prefix %>"><%= prefix %></a></h5></li>
      <% end %>
      <% if @package_prefixes.empty? %>
        <em>(no data yet)</em>
      <% end %>
    </ul>

  </div> <!-- class='col-md-6' -->
  <div class="col-md-6">
    <h3>Search Package</h3>
    <form action='/packages/-/search' class="form-inline">
      <div class="form-group">
        <input type="text" class="form-control" id="query" name="query" placeholder="Package to search...">
      </div>
      <button type="submit" class="btn btn-default">Search</button>
    </form>
  </div> <!-- class='col-md-6' -->

</div> <!-- class='row' -->
